@@ -890,20 +890,22 @@ proc xcircuit::promptobjectsize {} {
 proc xcircuit::promptborderwidth {} {
    global tcl_precision
    .dialog.textent.txt delete 0 end
-   ::set savep $tcl_precision
-   ::set tcl_precision 3
-   if {[catch {::set elist [xcircuit::select get]}]} {
+   set savep $tcl_precision
+   set tcl_precision 3
+   set elist [xcircuit::select get]
+   if {[llength $elist] == 0} {
       .dialog.bbar.okay configure -command \
-	   {xcircuit::config linewidth [.dialog.textent.txt get]; \
+	   {xcircuit::border set [.dialog.textent.txt get]; \
 	   wm withdraw .dialog}
-      .dialog.textent.title.field configure -text "Enter linewidth scale for page:"
-      .dialog.textent.txt insert 0 [xcircuit::config linewidth]
+      .dialog.textent.title.field configure -text "Enter default linewidth scale:"
+      .dialog.textent.txt insert 0 [xcircuit::border get]
    } else {
+      set eval [lindex $elist 0]
       .dialog.bbar.okay configure -command \
-	   {xcircuit::element border set [.dialog.textent.txt get]; \
+	   {xcircuit::border set [.dialog.textent.txt get]; \
 	   wm withdraw .dialog}
       .dialog.textent.title.field configure -text "Enter element linewidth:"
-      .dialog.textent.txt insert 0 [xcircuit::element $elist border get]
+      .dialog.textent.txt insert 0 [xcircuit::element $eval border get]
    }
    ::set tcl_precision $savep
    wm deiconify .dialog
@@ -915,7 +917,7 @@ proc xcircuit::promptlinewidth {} {
    .dialog.bbar.okay configure -command \
 	{xcircuit::config linewidth [.dialog.textent.txt get]; \
 	 wm withdraw .dialog}
-   .dialog.textent.title.field configure -text "Enter global linewidth scale:"
+   .dialog.textent.title.field configure -text "Enter page linewidth scaling:"
    .dialog.textent.txt delete 0 end
    ::set savep $tcl_precision
    ::set tcl_precision 3
