@@ -1424,16 +1424,21 @@ void makeparam(labelptr thislabel, char *key)
    /* intended parameter boundaries				*/
 
    if (textend > 0 && textend < textpos) {  	/* partial string */
-      begpart = splitstring(textend, &thislabel->string, areastruct.topinstance);
-      endpart = splitstring(textpos, &thislabel->string, areastruct.topinstance);
+      splitstring(textend, &thislabel->string, areastruct.topinstance);
+      splitstring(textpos, &thislabel->string, areastruct.topinstance);
 
-      /* note that "partial string" may overlap the beginning	*/
-      /* or the end, so deal with these instances.		*/
+      /* Because "splitstring" changes all the pointers, find the    */
+      /* stringpart structures at textend and textpos positions.     */
 
-      begpart = makesegment(&thislabel->string, (begpart->nextpart &&
-		textend > 1) ? begpart->nextpart : begpart);
-      endpart = makesegment(&thislabel->string, (endpart) ?
-		endpart->nextpart : NULL);
+      begpart = findstringpart(textend, NULL, thislabel->string,
+		areastruct.topinstance);
+      endpart = findstringpart(textpos, NULL, thislabel->string,
+		areastruct.topinstance);
+
+      /* Make the new segments for PARAM_START and PARAM_END.	*/
+
+      begpart = makesegment(&thislabel->string, begpart);
+      endpart = makesegment(&thislabel->string, endpart);
    }
    else {				/* full string */
       makesegment(&thislabel->string, thislabel->string);
