@@ -219,7 +219,10 @@ extern Boolean xc_tilde_expand(char *);
 extern short writelabel(FILE *, stringpart *, short *);
 extern char *writesegment(stringpart *, float *, int *);
 extern void writelabelsegs(FILE *, short *, stringpart *);
-extern void printobjects(FILE *, objectptr, short, short, objectptr **, short *, int);
+extern void printobjects(FILE *, objectptr, objectptr **, short *, int);
+extern void printrefobjects(FILE *, objectptr, objectptr **, short *);
+extern void printpageobject(FILE *, objectptr, short, short);
+
 
 /* from fontfile.c: */
 
